@@ -3,7 +3,7 @@ from pathlib import Path
 import sys
 from colorama import init
 from importlib_metadata import version
-from typing import Union, List, Optional
+from typing import Union, List, Optional, cast
 
 from data_check.data_check import DataCheck
 from data_check.config import DataCheckConfig
@@ -38,7 +38,6 @@ from data_check.config import DataCheckConfig
     help="shortcut for --print --print-format json",
 )
 @click.option(
-    "--gen",
     "--generate",
     "-g",
     "generate_expectations",
@@ -59,18 +58,18 @@ from data_check.config import DataCheckConfig
 @click.option(
     "--load",
     type=click.Path(),
-    help=f"load table data from a csv",
+    help="load table data from a csv",
 )
 @click.option(
     "--table",
     type=str,
-    help=f"table name to load data into",
+    help="table name to load data into",
 )
 @click.option(
     "--load-mode",
     type=str,
     default="truncate",
-    help=f"how to load the table: truncate (default), append or replace",
+    help="how to load the table: truncate (default), append or replace",
 )
 @click.option(
     "--load-tables", is_flag=True, help="load tables from a list of csv files"
@@ -92,7 +91,8 @@ from data_check.config import DataCheckConfig
 @click.option("--verbose", is_flag=True, help="print verbose output")
 @click.option("--traceback", is_flag=True, help="print traceback output for debugging")
 @click.option("--quiet", is_flag=True, help="do not print any output")
-@click.version_option(version=version("data-check"))
+@click.option("--log", type=click.Path(), help="write output to a log file")
+@click.version_option(version=cast(str, version("data-check")))
 @click.argument("files", nargs=-1, type=click.Path())
 def main(
     connection: str = "",
@@ -114,6 +114,7 @@ def main(
     verbose: bool = False,
     traceback: bool = False,
     quiet: bool = False,
+    log: Optional[Union[str, Path]] = None,
     files: List[Union[str, Path]] = [],
 ):
     """ FILES: list of checks files or folders"""
@@ -129,6 +130,8 @@ def main(
     )
     dc_config.generate_mode = generate_expectations
     dc_config.force = force
+    if log:
+        dc_config.log_path = Path(log)
 
     if not dc_config.connection:
         click.echo(f"unknown connection: {connection}")
@@ -143,6 +146,8 @@ def main(
         print_failed=print_failed,
         print_format=print_format,
         quiet=quiet,
+        # set log_path from config, so we can also use it from the config file
+        log_path=dc_config.log_path,
     )
 
     if load:
@@ -164,11 +169,13 @@ def main(
     dc.load_template()
 
     if sql_files:
+        dc.load_lookups()
         path_list = [Path(f) for f in files]
         dc.run_sql_files(path_list)
         sys.exit(0)
 
     if sql:
+        dc.load_lookups()
         if dc.run_sql_query(sql, output=output):
             sys.exit(0)
         else:
@@ -185,6 +192,7 @@ def main(
         else:
             sys.exit(1)
     else:
+        dc.load_lookups()
         result = dc.run(path_list)
         if not result:
             sys.exit(1)
