@@ -1,12 +1,18 @@
 from pathlib import Path
-from typing import List, Union
+from typing import List, Union, TYPE_CHECKING
 import subprocess
 
+if TYPE_CHECKING:
+    from data_check.output import DataCheckOutput
+
 
 class CmdStep:
-    def __init__(self, cmd: Union[str, List[str]], output) -> None:
+    def __init__(
+        self, cmd: Union[str, List[str]], output: "DataCheckOutput", print: bool = True
+    ) -> None:
         self.cmd = cmd
         self.output = output
+        self.print = print
 
     def _run_cmd(self, cmd: str, base_path: Path = Path(".")):
         self.output.print(f"# {cmd}")
@@ -19,7 +25,7 @@ class CmdStep:
         )
         assert process.stdout is not None
         with process.stdout:
-            self.output.handle_subprocess_output(process.stdout)
+            self.output.handle_subprocess_output(process.stdout, print=self.print)
         exitcode = process.wait()
         return exitcode == 0
 
