@@ -5,6 +5,7 @@ from typing import Optional, Dict, Any, Tuple
 
 TEMPLATE_FILE = "template.yml"
 CHECKS_PATH = "checks"
+LOOKUPS_PATH = "lookups"
 
 
 class DataCheckConfig:
@@ -27,6 +28,7 @@ class DataCheckConfig:
 
         self.generate_mode = False
         self.force = False
+        self.log_path: Optional[Path] = None
 
     @property
     def print_overall_result(self):
@@ -51,6 +53,10 @@ class DataCheckConfig:
     def template_path(self) -> Path:
         return self.project_path / CHECKS_PATH / TEMPLATE_FILE
 
+    @property
+    def lookups_path(self) -> Path:
+        return self.project_path / LOOKUPS_PATH
+
     def find_config(self, base_path: Path) -> Path:
         abs_base_path = base_path.absolute()
         config_path = abs_base_path / self.config_path
@@ -60,7 +66,7 @@ class DataCheckConfig:
             return self.find_config(abs_base_path.parent)
         return abs_base_path / self.config_path
 
-    def load_config(self, base_path=Path(".")):
+    def load_config(self, base_path: Path = Path(".")):
         try:
             config_path = self.find_config(base_path)
         except Exception:
@@ -75,6 +81,8 @@ class DataCheckConfig:
         self.base_path = base_path.absolute()
         self.config_path = config_path
         self.config = read_yaml(config_path)
+        _log_path = self.config.get("log", None)
+        self.log_path = Path(_log_path) if _log_path else None
         return self
 
     def set_connection(self, connection: str):
