@@ -1,4 +1,4 @@
-from typing import List, Tuple
+from typing import List, Tuple, Union
 import pandas as pd
 from dateutil.parser import isoparse as _isoparse
 import math
@@ -9,7 +9,7 @@ def parse_date_columns(df: pd.DataFrame) -> Tuple[List[str], pd.DataFrame]:
     Returns a tuple with the list of the column names that were parsed as dates
     and the DataFrame with these columns replaced as datetime.
     """
-    _date_columns = []
+    _date_columns: List[str] = []
     for column_name, column in df.items():
         # only try to convert, if some values exist in the column
         if not column.isna().all():
@@ -22,7 +22,7 @@ def parse_date_columns(df: pd.DataFrame) -> Tuple[List[str], pd.DataFrame]:
     return _date_columns, df
 
 
-def isoparse(column):
+def isoparse(column: Union[int, float, str, None]):
     if isinstance(column, float) and math.isnan(column):
         column = ""
     if column is None or len(str(column)) == 0:
